#! /bin/bash -xue

# Generates an 2:1 ramp (~26.5 degrees) geometry and inviscid grid
# with a parasolid CAD kernel, batchEx, and a volume-source aware AFLR3.

output='ramp'

cat > .aflr3 << EOF
1
0
0
1.10
1.10
1.10
2
0.0
1.0
250000.
1.0
-ogrid ${output}.lb8.ugrid
EOF

PI=$( echo '4*a(1)' | bc -l )
RAD_TO_DEG=$( echo "180/${PI}" | bc -l )
RAMP_ANGLE=$( echo "a(0.5/1.0)*${RAD_TO_DEG}" | bc -l )

linux32 batchEx -parasolid \
  -box -2 0  0    5 0.5 2 \
  -box -3 0 -1    3 0.5 1 -v -1 -rot 0 1 0 -${RAMP_ANGLE} -trans 1 0 0.5 \
  -box  1 0 -0.5  2 0.5 1 \
  -subtract 1 2 \
  -subtract 4 3 \
  -model -1 -v -1 \
  -slip    z+0.0    -f 1 -mv -1 \
  -slip    z+1.0    -f 2 -mv -1 \
  -sym     y+0.0    -f 3 -mv -1 \
  -riemann x-2.0    -f 4 -mv -1 \
  -sym     y+0.5    -f 5 -mv -1 \
  -extrap  x+3.0    -f 6 -mv -1 \
  -slip    ramp-2:1 -f 7 -mv -1 \
  -slip    z+0.5    -f 8 -mv -1 \
  -m 1 -s 3 -sdef 0.1 \
  -bc ${output}.mapbc \
  -aflr3 ${output} \
  -o ${output}

./${output}.script
